import os


class Jbird:

    # # path of the data storage
    path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'data')

    # set variables, create directory and files
    def _prepare(self):

        # create working directory if not exists
        if not os.path.exists(self.path):
            os.mkdir(self.path)


    def j(self):
        print('j')


import os
import hashlib
from .Jbird import Jbird


class Key(Jbird):

	# name and full path to the keys file
	file = '__keys.bin'

	# lengths of key attributes (in bytes)
	hash_len, pos_len, vol_len = 40, 5, 5
	chunk_len = hash_len, pos_len, vol_len

	# set variables, create directory and files
	def __init__(self):
		self._prepare()

		# create keys file if not exists
		if not os.path.isfile(os.path.join(self.path, self.file)):
			open(os.path.join(self.path, self.file), 'w').close()

	# return hash of the string in bytes (!)
	def hash(self, txt: str) -> bytes:
		txt_bytes = str.encode(txt)
		hash_obj = hashlib.sha1(txt_bytes)
		hash_str = hash_obj.hexdigest()
		hash_bytes = str.encode(hash_str)
		return hash_bytes

	# insert a new chunk and shift others toward the end of file
	def push(self, pos: int) -> bool:
		pass

	# delete a chunk and shift others backward to the start of file
	def pop(self, pos: int) -> bool:
		pass

	# write a chunk
	def write(self, chunk: bytes, pos: int) -> bool:
		with open(os.path.join(self.path, self.file), 'r+b') as f:
			f.seek(pos)
			f.write(chunk)
		return True

	# read a chunk
	def read(self, pos: int) -> bytes:
		pass

	def k(self):
		print('key')
		self.j()



from setuptools import setup

setup(name='jbird',
      version='0.0.1',
      description='JSON NoSQL database',
      packages=['jbird'],
      author_email='notdepot@gmail.com',
      zip_safe=False)


import os
from .Jbird import Jbird


class Value(Jbird):

    # name and full path to the keys file
    file = '__values.dat'

    # set variables, create directory and files
    def __init__(self):
        self._prepare()

        # create keys file if not exists
        if not os.path.isfile(os.path.join(self.path, self.file)):
            open(os.path.join(self.path, self.file), 'w').close()

    # return pos in bytes (!)
    def pos(self, pos: int) -> bytes:
        return int(pos).to_bytes(5, 'big')

    # return len in bytes (!)
    def vol(self, vol: int) -> bytes:
        return int(vol).to_bytes(5, 'big')

    def v(self):
        print('value')
        self.j()
